==> nextcloud-28.0.3.tgz: nextcloud/apps/weather_status/l10n/es.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Direcciones desconocidas",
    "No result." : "Sin resultados.",
    "Malformed JSON data." : "Datos JSON mal formados.",
    "Error" : "Error",
    "Weather status" : "Estado del tiempo",
    "Weather status in your dashboard" : "El estado del tiempo en tu dashboard",
    "Detect location" : "Detectar la ubicación",
    "Set custom address" : "Configurar una dirección personalizada",
    "Favorites" : "Favoritos",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} Cielo depejado más tarde hoy",
    "{temperature} {unit} clear sky" : "{temperature} {unit} Cielo despejado",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} nublado más tarde hoy",
    "{temperature} {unit} cloudy" : "{temperature} {unit} Nublado",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} buen tiempo más tarde hoy",
    "{temperature} {unit} fair weather" : "{temperature} {unit} Buen día",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} parcialmente nublado más tarde hoy",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} Parcialmente nublado",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} con niebla más tarde hoy",
    "{temperature} {unit} foggy" : "{temperature} {unit} Con brumas",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} lluvia leve más tarde hoy",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} lluvia leve",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} lluvia más tarde hoy",
    "{temperature} {unit} rainfall" : "{temperature} {unit} lluvia",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} lluvia fuerte más tarde hoy",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} lluvia fuerte",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} chubascos más tarde hoy",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} chubascos",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} chubascos leves más tarde hoy",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} chubascos leves",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} chubascos fuertes más tarde hoy",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} chubascos fuertes",
    "More weather for {adr}" : "Más previsiones para {adr}",
    "Loading weather" : "Cargando previsión del tiempo",
    "Remove from favorites" : "Quitar de favoritos",
    "Add as favorite" : "Añadir como favorito",
    "You are not logged in." : "No ha iniciado sesión.",
    "There was an error getting the weather status information." : "Ha habido un error al obtener la información sobre la previsión del tiempo.",
    "No weather information found" : "No se ha encontrado información del tiempo",
    "Location not found" : "Ubicación no encontrada",
    "There was an error setting the location address." : "Ha habido un error al ajustar la dirección de la ubicación.",
    "There was an error setting the location." : "Ha habido un error al ajustar la ubicación.",
    "There was an error saving the mode." : "Ha habido un error al guardar el modo.",
    "There was an error using personal address." : "Ha habido un error al ajustar la dirección personal.",
    "Set location for weather" : "Seleccione la ubicación para el tiempo",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Integración de la previsión del tiempo en la app Dashboard.\n   La posición del panel puede ser determinada automáticamente o definida manualmente. El panel muestra una previsión de tiempo de las próximas 6 horas.\n   Este panel también puede ser integrado en otros sitios, como la app de Calendario."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.9.tgz: nextcloud/apps/weather_status/l10n/es.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Direcciones desconocidas",
    "No result." : "Sin resultados.",
    "Malformed JSON data." : "Datos JSON mal formados.",
    "Error" : "Error",
    "Weather status" : "Estado del tiempo",
    "Weather status in your dashboard" : "El estado del tiempo en tu dashboard",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estado del clima integrado en la aplicación Tablero.\n          La posición geográfica del usuario puede determinarse automáticamente o definirse manualmente. Luego se muestra un pronóstico a 6 horas.\n          Este estado también puede integrarse en otros lugares, como la aplicación Calendario.",
    "Detect location" : "Detectar la ubicación",
    "Set custom address" : "Configurar una dirección personalizada",
    "Favorites" : "Favoritos",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} Cielo despejado más tarde hoy",
    "{temperature} {unit} clear sky" : "{temperature} {unit} Cielo despejado",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} nublado más tarde hoy",
    "{temperature} {unit} cloudy" : "{temperature} {unit} Nublado",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} buen clima más tarde hoy",
    "{temperature} {unit} fair weather" : "{temperature} {unit} Buen clima",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} parcialmente nublado más tarde hoy",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} Parcialmente nublado",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} con niebla más tarde hoy",
    "{temperature} {unit} foggy" : "{temperature} {unit} Con brumas",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} lluvia leve más tarde hoy",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} lluvia leve",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} lluvia más tarde hoy",
    "{temperature} {unit} rainfall" : "{temperature} {unit} lluvia",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} lluvioso más tarde hoy",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} muy lluvioso",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} chubascos más tarde hoy",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} chubascos",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} chubascos leves más tarde hoy",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} chubascos leves",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} chubascos fuertes más tarde hoy",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} chubascos fuertes",
    "More weather for {adr}" : "Más previsiones para {adr}",
    "Loading weather" : "Cargando previsión del tiempo",
    "Remove from favorites" : "Quitar de favoritos",
    "Add as favorite" : "Añadir como favorito",
    "You are not logged in." : "No ha iniciado sesión.",
    "There was an error getting the weather status information." : "Ha habido un error al obtener la información sobre la previsión del tiempo.",
    "No weather information found" : "No se ha encontrado información del tiempo",
    "Location not found" : "Ubicación no encontrada",
    "There was an error setting the location address." : "Ha habido un error al ajustar la dirección de la ubicación.",
    "There was an error setting the location." : "Ha habido un error al ajustar la ubicación.",
    "There was an error saving the mode." : "Ha habido un error al guardar el modo.",
    "There was an error using personal address." : "Ha habido un error al ajustar la dirección personal.",
    "Set location for weather" : "Seleccione la ubicación para el tiempo",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Integración de la previsión del tiempo en la app Dashboard.\n   La posición del panel puede ser determinada automáticamente o definida manualmente. El panel muestra una previsión de tiempo de las próximas 6 horas.\n   Este panel también puede ser integrado en otros sitios, como la app de Calendario."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
